Function get_inverse_GRAM() allows to get inverse Gram matrix based on given
positive regularization constant lambda
Function check_positive_definite() returns logical value about n trials on
'is Gram matrix positive definite or not?' Just incorrect trial returns FALSE
get_inverse_GRAM(G, l = 1e-06, check_pos_def = FALSE)check_positive_definite(G, n = 10)
Function get_inverse_GRAM() returns the inverse Gram matrix
based on the given positive regularization constant lambda l
Function check_positive_definite() returns logical value:
TRUE if Gram matrix is positive definite, and FALSE if it is not
Gram matrix gotten via GRAM_iKernel() function
Lambda parameter or positive regularization constant
Logical parameter to check the Gram matrix is positive definite or do not check
Number of iterations to check the positive definite property
check_positive_definite(): The function to check the positive definite property of Gram matrix