The function to get feature representation in RKHS based on Voronoi diagram for WHOLE dataset
get_voronoi_feature(
psi = 40,
t = 350,
data,
talkative = FALSE,
Matrix_Voronoi = NULL
)add_new_point_iKernel(data, d1, Matrix_Voronoi, dissim, t, psi, nr)
Feature representation in RKHS based on Voronoi diagram for WHOLE dataset
RKHS mapping for a new point based on Isolation Kernel mapping
Integer number related to the size of each Voronoi diagram
Integer number of trees in Isolation Kernel or dimension of RKHS
dataset of points, rows - points, columns - dimensions of a point
logical. If TRUE then print messages, FALSE for the silent execution
Matrix of Voronoi diagrams, if it is NULL then the function will calculate Matrix_Voronoi
Data point - usually it is an observation data point
Matrix of dissimilarity or distances between all points.
Integer number of rows in matrix of distances (dissim) and also the size of dataset
add_new_point_iKernel(): The function to get RKHS mapping based on Isolation Kernel for a new point