get_voronoi_feature_PART_dataset: The function to get feature representation in RKHS based on Voronoi diagram for PART of dataset
Description
get_voronoi_feature_PART_dataset() function returns
the feature (mapping) representation in RKHS based on Voronoi diagram for NEW PART of dataset.
The Matrix_Voronoi is based on the PREVIOUS dataset.
The NEW PART of dataset will appear at the end of PREVIOUS dataset
Usage
get_voronoi_feature_PART_dataset(
data,
talkative = FALSE,
start_row,
Matrix_Voronoi
)
Value
List of three matrices: Matrix_Voronoi, Matrix_iKernel and dissim
Arguments
- data
Data.frame of new points
- talkative
Logical parameter to print or do not print messages
- start_row
Row number from which a new data should be added
- Matrix_Voronoi
Matrix of Voronoi diagrams based on the PREVIOUS dataset