GET_SUBSET: The function to get subset with size psi for Voronoi diagram
Description
The function to get subset with size psi for Voronoi diagram
Usage
GET_SUBSET(data_set, pnts)
Value
Subset of data_set with columns pnts
Arguments
- data_set
Data.frame of Voronoi diagram
- pnts
Integer vector of indexes of columns of the data_set